@@ -197,12 +197,15 @@ def inject_crystal_symmetry(command, directives, program_name, log=None):
 # =========================================================================
 
 # Programs that accept only positional file arguments (no key=value params)
+# Programs that take ONLY file arguments (no key=value strategy params).
+# sanitize_command strips all key=value tokens from these programs.
+# NOTE: Do NOT add programs here that accept strategy_flags (like resolution).
+# validation_cryoem is intentionally excluded — it requires resolution=X.
 _PROBE_ONLY_FILE_PROGRAMS = frozenset({
     'phenix.model_vs_data',  'mmtbx.model_vs_data',
     'phenix.xtriage',        'mmtbx.command_line.xtriage',
     'phenix.molprobity',
     'phenix.mtriage',
-    'phenix.validation_cryoem',
 })
 
 # Placeholder patterns for sanitize
@@ -212,8 +215,12 @@ _PLACEHOLDER_PATTERNS = (
 )
 
 # Universal keys that are always allowed for any program
+# NOTE: nproc is intentionally NOT here.  Not all programs accept nproc
+# (e.g. map_correlations, validation_cryoem).  Programs that do accept it
+# list nproc in their strategy_flags (added to allowlist automatically)
+# or defaults (inject_program_defaults adds it after sanitize).
 _UNIVERSAL_KEYS = {
-    'nproc', 'output_prefix', 'output_dir', 'output_directory',
+    'output_prefix', 'output_dir', 'output_directory',
     'prefix', 'overwrite', 'verbose', 'quiet',
 }
 
@@ -308,6 +315,11 @@ def sanitize_command(command, program_name=None, bad_inject_params=None,
         bad_inject_params = set()
 
     # ── 1. Probe-only programs: strip ALL key=value tokens ─────────────
+    # EXCEPT: file-path values (half_map=/path/to/file.mrc) and
+    # data-label selection parameters (obs_labels, labels, data_labels).
+    # The label params come from the error-recovery system when an MTZ
+    # has ambiguous data arrays — they MUST survive sanitization so the
+    # retry actually resolves the ambiguity.
     if program_name in _PROBE_ONLY_FILE_PROGRAMS:
         # Pre-pass: multi-word placeholder patterns
         _MULTIWORD_PLACEHOLDER_RE = re.compile(
@@ -338,9 +350,22 @@ def sanitize_command(command, program_name=None, bad_inject_params=None,
                 val_part = tok.split('=', 1)[1].strip("'\"").replace('\x00', ' ')
                 import os.path as _osp
                 _ext = _osp.splitext(val_part)[1].lower()
+                # Check if key is a data-label selection parameter
+                # (from error recovery for ambiguous MTZ arrays)
+                key_part = tok.split('=', 1)[0].split('.')[-1].lower()
+                _is_label_param = key_part in (
+                    'obs_labels', 'labels', 'data_labels',
+                    'anomalous_labels', 'r_free_flags_labels',
+                )
                 if '/' in val_part or _ext in _FILE_EXTS:
                     # Looks like a file path — keep it
                     stripped_tokens.append(tok_display)
+                elif _is_label_param:
+                    # Recovery-injected label selection — keep it
+                    stripped_tokens.append(tok_display)
+                    if log:
+                        log("  [sanitize_command] kept label param %r on %s "
+                            "(recovery-safe)" % (tok_display, program_name))
                 else:
                     if log:
                         log("  [sanitize_command] removed param %r from %s "
@@ -528,7 +553,7 @@ def inject_user_params(command, user_advice, program_name='',
         r')'
     )
 
-    _UNIVERSAL_SCOPES = {'general', 'output', 'job', 'data_manager', 'nproc'}
+    _UNIVERSAL_SCOPES = {'general', 'output', 'job', 'data_manager'}
     _SKIP_KEYS = {'e', 'i', 'http', 'https', 'key', 'param', 'setting'}
 
     # Load strategy_flags allowlist for Rule D consistency: bare (undotted)
